==> qtjambi-qt3drender-5.15.5-sources.jar: io/qt/qt3d/render/QCullFace.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies whether front or back face culling is enabled</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html">Qt3DRender::QCullFace</a></p>
 */
public class QCullFace extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCullFace.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#CullingMode-enum">Qt3DRender::QCullFace::CullingMode</a></p>
     */
    public enum CullingMode implements io.qt.QtEnumerator {
        NoCulling(0),
        Front(1028),
        Back(1029),
        FrontAndBack(1032);

        private CullingMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static CullingMode resolve(int value) {
            switch (value) {
            case 0: return NoCulling;
            case 1028: return Front;
            case 1029: return Back;
            case 1032: return FrontAndBack;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#mode-prop">Qt3DRender::QCullFace::modeChanged(Qt3DRender::QCullFace::CullingMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="mode")
    public final Signal1<io.qt.qt3d.render.QCullFace.CullingMode> modeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCullFace(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCullFace() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#QCullFace">Qt3DRender::QCullFace::QCullFace(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QCullFace(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCullFace instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#mode-prop">Qt3DRender::QCullFace::mode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="mode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QCullFace.CullingMode mode(){
        return io.qt.qt3d.render.QCullFace.CullingMode.resolve(mode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int mode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#mode-prop">Qt3DRender::QCullFace::setMode(Qt3DRender::QCullFace::CullingMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="mode")
    public final void setMode(io.qt.qt3d.render.QCullFace.CullingMode mode){
        setMode_native_Qt3DRender_QCullFace_CullingMode(QtJambi_LibraryUtilities.internal.nativeId(this), mode.value());
    }
    
    private native void setMode_native_Qt3DRender_QCullFace_CullingMode(long __this__nativeId, int mode);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCullFace(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCullFace(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCullFace instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QCullFace.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies whether front or back face culling is enabled</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html">Qt3DRender::QCullFace</a></p>
 */
public class QCullFace extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCullFace.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#CullingMode-enum">Qt3DRender::QCullFace::CullingMode</a></p>
     */
    public enum CullingMode implements io.qt.QtEnumerator {
        NoCulling(0),
        Front(1028),
        Back(1029),
        FrontAndBack(1032);

        private CullingMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static CullingMode resolve(int value) {
            switch (value) {
            case 0: return NoCulling;
            case 1028: return Front;
            case 1029: return Back;
            case 1032: return FrontAndBack;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#mode-prop">Qt3DRender::QCullFace::modeChanged(Qt3DRender::QCullFace::CullingMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="mode")
    public final Signal1<io.qt.qt3d.render.QCullFace.CullingMode> modeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCullFace(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCullFace() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#QCullFace">Qt3DRender::QCullFace::QCullFace(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QCullFace(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCullFace instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#mode-prop">Qt3DRender::QCullFace::mode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="mode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QCullFace.CullingMode mode(){
        return io.qt.qt3d.render.QCullFace.CullingMode.resolve(mode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int mode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcullface.html#mode-prop">Qt3DRender::QCullFace::setMode(Qt3DRender::QCullFace::CullingMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="mode")
    public final void setMode(io.qt.qt3d.render.QCullFace.CullingMode mode){
        setMode_native_Qt3DRender_QCullFace_CullingMode(QtJambi_LibraryUtilities.internal.nativeId(this), mode.value());
    }
    
    private native void setMode_native_Qt3DRender_QCullFace_CullingMode(long __this__nativeId, int mode);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCullFace(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCullFace(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCullFace instance, QDeclarativeConstructor constructor);
    
}
